timespantools
=============

.. automodule:: abjad.tools.timespantools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.timespantools.Timespan.Timespan.Timespan
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.TimespanInventory
